Documentation
¶
Overview ¶
Package ssh provides kool ssh utilities (local port forward, etc.).
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func BuildSSHForwardArgv ¶
BuildSSHForwardArgv returns ssh args after the binary name for a local forward.
func HandleWith ¶
func HandleWith(args []string, opts HandleOpts) error
HandleWith is the injectable entry used by tests.
Types ¶
type HandleOpts ¶
type HandleOpts struct {
Stdout io.Writer
Stderr io.Writer
// RunSSH runs the ssh process and blocks until exit. Nil → real exec.
// argv is the full argument list after "ssh" (not including binary name).
RunSSH func(argv []string) error
// WaitLocalReady waits until localPort accepts TCP. Nil → default dial loop.
WaitLocalReady func(localPort int, timeout time.Duration) error
}
HandleOpts injects IO and process runner for tests.
Click to show internal directories.
Click to hide internal directories.